/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#include "os/mynewt.h"

#if MYNEWT_VAL(FS_TEST_LITTLEFS)

#if !MYNEWT_VAL(LITTLEFS_FLASH_AREA)
#error "No LITTLEFS_FLASH_AREA defined"
#endif

#include "lfs.h"

int littlefs_reformat(void);
int littlefs_init(void);

int
fs_lowlevel_init(void)
{
    int rc;

    (void)rc;

    /* always force format before starting */
#if MYNEWT_VAL(FS_TEST_FORCE_REFORMAT)
    rc = littlefs_reformat();
    if (rc) {
        return rc;
    }
#endif

    return littlefs_init();
}

#endif
